@@ -19,6 +19,8 @@ import jsii
 import publication
 import typing_extensions
 
+from typeguard import check_type
+
 from ._jsii import *
 
 import aws_cdk.aws_cognito
@@ -41,7 +43,7 @@ class UserIdentity(
         scope: constructs.Construct,
         id: builtins.str,
         *,
-        identity_pool_options: typing.Optional[aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps] = None,
+        identity_pool_options: typing.Optional[typing.Union[aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps, typing.Dict[str, typing.Any]]] = None,
         user_pool: typing.Optional[aws_cdk.aws_cognito.UserPool] = None,
     ) -> None:
         '''
@@ -52,13 +54,17 @@ class UserIdentity(
 
         :stability: experimental
         '''
+        if __debug__:
+            type_hints = typing.get_type_hints(UserIdentity.__init__)
+            check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
+            check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = UserIdentityProps(
             identity_pool_options=identity_pool_options, user_pool=user_pool
         )
 
         jsii.create(self.__class__, self, [scope, id, props])
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="identityPool")
     def identity_pool(self) -> aws_cdk.aws_cognito_identitypool_alpha.IdentityPool:
         '''
@@ -66,7 +72,7 @@ class UserIdentity(
         '''
         return typing.cast(aws_cdk.aws_cognito_identitypool_alpha.IdentityPool, jsii.get(self, "identityPool"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="userPool")
     def user_pool(self) -> aws_cdk.aws_cognito.UserPool:
         '''
@@ -74,7 +80,7 @@ class UserIdentity(
         '''
         return typing.cast(aws_cdk.aws_cognito.UserPool, jsii.get(self, "userPool"))
 
-    @builtins.property # type: ignore[misc]
+    @builtins.property
     @jsii.member(jsii_name="userPoolClient")
     def user_pool_client(self) -> typing.Optional[aws_cdk.aws_cognito.UserPoolClient]:
         '''
@@ -95,7 +101,7 @@ class UserIdentityProps:
     def __init__(
         self,
         *,
-        identity_pool_options: typing.Optional[aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps] = None,
+        identity_pool_options: typing.Optional[typing.Union[aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps, typing.Dict[str, typing.Any]]] = None,
         user_pool: typing.Optional[aws_cdk.aws_cognito.UserPool] = None,
     ) -> None:
         '''(experimental) Properties which configures the Identity Pool.
@@ -106,7 +112,11 @@ class UserIdentityProps:
         :stability: experimental
         '''
         if isinstance(identity_pool_options, dict):
-            identity_pool_options = aws_cdk.aws_cognito_identitypool_alpha.IdentityPoolProps(**identity_pool_options)
+            identity_pool_options = IdentityPoolProps(**identity_pool_options)
+        if __debug__:
+            type_hints = typing.get_type_hints(UserIdentityProps.__init__)
+            check_type(argname="argument identity_pool_options", value=identity_pool_options, expected_type=type_hints["identity_pool_options"])
+            check_type(argname="argument user_pool", value=user_pool, expected_type=type_hints["user_pool"])
         self._values: typing.Dict[str, typing.Any] = {}
         if identity_pool_options is not None:
             self._values["identity_pool_options"] = identity_pool_options
